==> zoneminder_1.32.3.orig.tar.xz: zoneminder-1.32.3/web/api/app/Model/User.php <==
<?php
App::uses('AppModel', 'Model');
/**
 * User Model
 *
 * @property Monitor $Monitor
 * @property Frame $Frame
 */
class User extends AppModel {

    public $validate = array(
        'Username' => array(
            'required' => array(
                'rule' => array('notEmpty'),
                'message' => 'A username is required'
            )
        ),
        'Password' => array(
            'required' => array(
                'rule' => array('notEmpty'),
                'message' => 'A password is required'
            )
        )
    );

/**
 * Use table
 *
 * @var mixed False or table name
 */
	public $useTable = 'Users';

/**
 * Primary key field
 *
 * @var string
 */
	public $primaryKey = 'Id';

/**
 * Display field
 *
 * @var string
 */
	public $displayField = 'Username';


	//The Associations below have been created with all possible keys, those that are not needed can be removed

/**
 * belongsTo associations
 *
 * @var array
 */
	public $belongsTo = array(
		/*'Monitor' => array(
			'className' => 'Monitor',
			'foreignKey' => 'MonitorId',
			'conditions' => '',
			'fields' => '',
			'order' => ''
		)
*/
	);

/**
 * hasMany associations
 *
 * @var array
 */
	public $hasMany = array(
/*
		'Frame' => array(
			'className' => 'Frame',
			'foreignKey' => 'UserId',
			'dependent' => true,
			'conditions' => '',
			'fields' => '',
			'order' => '',
			'limit' => '',
			'offset' => '',
			'exclusive' => '',
			'finderQuery' => '',
			'counterQuery' => ''
		)
*/
	);

}

==> zoneminder_1.36.37+dfsg1.orig.tar.xz: zoneminder-1.36.37/web/api/app/Model/User.php <==
<?php
App::uses('AppModel', 'Model');
/**
 * User Model
 *
 */
class User extends AppModel {

    public $validate = array(
        'Username' => array(
            'required' => array(
                'rule' => array('notEmpty'),
                'message' => 'A username is required'
            )
        ),
        'Password' => array(
            'required' => array(
                'rule' => array('notEmpty'),
                'message' => 'A password is required'
            )
        )
    );

    function beforeFind($query) {
      if ( empty($query['fields']) ) {
        $schema = $this->schema();
        unset($schema['Password']);

        foreach (array_keys($schema) as $field) {
          $query['fields'][] = $this->alias . '.' . $field;
        }
        return $query;
      }
      return parent::beforeFind($query);
    }

    public function beforeSave($options = array()) {
      if (!empty($this->data['User']['Password'])) {
        $this->data['User']['Password'] = password_hash($this->data['User']['Password'], PASSWORD_BCRYPT);
      }
      return true;
    }  # end function beforeSave

/**
 * Use table
 *
 * @var mixed False or table name
 */
	public $useTable = 'Users';

/**
 * Primary key field
 *
 * @var string
 */
	public $primaryKey = 'Id';

/**
 * Display field
 *
 * @var string
 */
	public $displayField = 'Username';


	//The Associations below have been created with all possible keys, those that are not needed can be removed

/**
 * belongsTo associations
 *
 * @var array
 */
	public $belongsTo = array(
	);

/**
 * hasMany associations
 *
 * @var array
 */
	public $hasMany = array(
	);

}
